ControlFlow

Type Alias ControlFlow 

pub type ControlFlow<T> = ControlFlow<(), T>;
Return type for visitor methods that may either continue with a child visitor or pause parsing. See the module-level docs for the control-flow model.

Aliased Type

pub enum ControlFlow<T> {
    Continue(T),
    Break(()),
}

Variants

1.55.0

Continue(T)

Move on to the next phase of the operation as normal.

1.55.0

Break(())

Exit the operation without running subsequent phases.