pub struct AstBuilder { /* private fields */ }Available on crate feature
alloc only.Expand description
ProgramVisitor that builds an owned Program and collects Diagnostics.
Used by parse; typically not constructed by users.
Implementations
Sourceimpl AstBuilder
impl AstBuilder
Sourcepub fn finish(self) -> Result<Program, Diagnostics>
pub fn finish(self) -> Result<Program, Diagnostics>
Returns the built Program, or Err with the collected Diagnostics if any diagnostic was emitted.